#-*- coding:utf-8 -*-

#    Gedit lf_to_br plugin version 3.1.0
#    Copyright © 2011-2013 sasakima-nao <sasakimanao@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    2013.11.03 Version 3.1.0
#    Support Gedit 3.8 (Python3)
#    Support CRLF
#    Fix: GtkActionGroup Name
#
#    2011.06.04 Version 3.0.0

from gi.repository import GObject, Gedit, Gtk

ui_str = """<ui>
    <menubar name="MenuBar">
        <menu name="EditMenu" action="Edit">
            <placeholder name="EditOps_3">
                <menuitem name="LF_ON_BR" action="LF_ON_BR"/>
            </placeholder>
        </menu>
    </menubar>
</ui>
"""

class LF_on_BR_Plugin(GObject.Object, Gedit.WindowActivatable):
    __gtype_name__ = "LF_on_BR_Plugin"
    window = GObject.property(type=Gedit.Window)
    def __init__(self):
        GObject.Object.__init__(self)

    def do_activate(self):
        # GtkUIManager を得る
        manager = self.window.get_ui_manager()
        # GtkActionGroup を新規で作成
        self._action_group = Gtk.ActionGroup("LFonBRActions")
        # GtkActionEntry を作成
        # name, stock_id, label, accelerator, tooltip, callback
        actions = [("LF_ON_BR", None, "LF 位置に <br />", None, "選択範囲の改行位置に <br /> を追記", self.on_lf_to_br_activate)]
        # GtkActionGroup に挿入
        self._action_group.add_actions(actions)
        # GtkUIManager に追加
        manager.insert_action_group(self._action_group, -1)
        self._ui_id = manager.add_ui_from_string(ui_str)

    def do_deactivate(self):
        manager = self.window.get_ui_manager()
        manager.remove_ui(self._ui_id)
        manager.remove_action_group(self._action_group)
        manager.ensure_update()

    def do_update_state(self):
        pass

    def on_lf_to_br_activate(self, action, data=None):
        view = self.window.get_active_view()
        buf = view.get_buffer()
        try:
            begin, end = buf.get_selection_bounds()
        except:
            self.messagebox("変換したいテキストを選択してください")
            return
        text = begin.get_text(end)
        lf = "\n"
        if "\r" in text:
            lf = "\r\n"
        lines = text.split(lf)
        result = []
        for line in lines:
            result.append("{0}<br />".format(line))
        buf.delete_selection(True, True)
        buf.insert_at_cursor(lf.join(result))

    def messagebox(self, text):
        dlg = Gtk.MessageDialog(
                self.window,
                Gtk.DialogFlags.MODAL,
                Gtk.MessageType.WARNING,
                Gtk.ButtonsType.OK,
                text)
        r = dlg.run()
        dlg.destroy()
